@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use strict;
 use warnings;
@@ -166,7 +166,7 @@ sub number_ranger {
 sub name_ranger {
     my %args = @_;
     # Set defaults.
-    $args{gender}  ||= 0;
+    $args{gender}  ||= 'b';
     $args{names}   ||= 2;
     $args{country} ||= 'us';
     $args{N}       ||= NDATA;
@@ -390,24 +390,26 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
   use Mock::Populate;
   # * Call each function below with Mock::Populate::foo(...
-  $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0, N => $n);
-  $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1, N => $n);
-  $create = date_ranger(start => '1900-01-01', end => '2020-12-31', N => $n);
-  $modify = date_modifier($offset, @$create);
-  $times  = time_ranger(stamp => 1, start => '01:02:03' end =>'23:59:59', N => $n);
-  $people = name_ranger(gender => 'b', names => 2, country => 'us', N => $n);
-  $email  = email_ranger(@$people);
-  $shuff  = shuffler($n, qw(foo bar baz goo ber buz));
-  $stats  = distributor(type => 'u', prec => 4, dof => 2, N => $n);
-  $string = string_ranger(length => 32, type => 'base64', N => $n);
-  $imgs   = image_ranger(size => 10, N => $n);  # *size is density, not pixel dimension
-  $coll   = collate($ids, $people, $email, $create, $times, $modify, $times);
+  my $n      = 5;
+  my $offset = 11;
+  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0, N => $n);
+  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1, N => $n);
+  my $create = date_ranger(start => '1900-01-01', end => '2020-12-31', N => $n);
+  my $modify = date_modifier($offset, @$create);
+  my $times  = time_ranger(stamp => 1, start => '01:02:03', end =>'23:59:59', N => $n);
+  my $people = name_ranger(gender => 'b', names => 2, country => 'us', N => $n);
+  my $email  = email_ranger(@$people);
+  my $shuff  = shuffler($n, qw(foo bar baz goo ber buz));
+  my $stats  = distributor(type => 'u', prec => 4, dof => 2, N => $n);
+  my $string = string_ranger(length => 32, type => 'base64', N => $n);
+  my $imgs   = image_ranger(size => 10, N => $n);  # *size is density, not pixel dimension
+  my $coll   = collate($ids, $people, $email, $create, $times, $modify, $times);
 
 =head1 DESCRIPTION
 
@@ -451,15 +453,16 @@ Return a new list of random future dates, based on the offset.
     N     => $n,
   );
 
-Return a list of B<N> random times within a range.  The start and end times, and
-desired number of data-points are all optional.  The defaults are:
+Return a list of B<N> random times within a range.  The stamp, start and end
+times, and desired number of data-points are all optional.  The defaults are:
 
   stamp: 1 (boolean)
   start: 00-00-00
   end: now (computed if not given)
   N: 10
 
-The times must be given as C<HH-MM-SS> strings.
+The times must be given as C<HH-MM-SS> strings.  The B<stamp> argument
+determines if a time-stamp or the number of seconds should be returned.
 
 =head2 number_ranger()
 
@@ -498,12 +501,16 @@ desired number of data-points are all optional.  The defaults are:
   country: us
   N: 10
 
+This routine uses L<Mock::Person>.  Please see that module for the country
+identifiers to use.
+
 =head2 email_modifier()
 
   $results = email_modifier(@people)
   # first.last@example.{com,net,org,edu}
 
-Return a list of email addresses based on a list of given names.
+Return a list of email addresses based on a list of given names.  Any names with
+unicode are run through L<Text::Unidecode>.
 
 =head2 distributor()
 
@@ -523,6 +530,8 @@ The defaults are:
   degrees-of-freedom: 2
   N: 10
 
+This routine uses L<Statistics::Distributions>.
+
 =head3 Types
 
 This function uses single letter identifiers:
@@ -588,6 +597,8 @@ The defaults are:
   N: 10
   size: 8
 
+This routine uses L<Image::Dot>.
+
 =head2 collate()
 
   $rows = collate(@columns)
